@@ -33,9 +33,10 @@
 #  define KWAYLANDCLIENT_DEPRECATED_NO_EXPORT KWAYLANDCLIENT_NO_EXPORT KWAYLANDCLIENT_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KWAYLANDCLIENT_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KWAYLANDCLIENT_NO_DEPRECATED
+#    define KWAYLANDCLIENT_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
