@@ -34,6 +34,8 @@ struct wl_seat;
 struct wl_shell;
 struct wl_shm;
 struct wl_subcompositor;
+struct wl_text_input_manager;
+struct zwp_text_input_manager_v2;
 struct _wl_fullscreen_shell;
 struct org_kde_kwin_outputmanagement;
 struct org_kde_kwin_outputdevice;
@@ -47,6 +49,14 @@ struct org_kde_kwin_slide_manager;
 struct org_kde_plasma_shell;
 struct org_kde_plasma_window_management;
 struct org_kde_kwin_server_decoration_manager;
+struct xdg_shell;
+struct zxdg_shell_v6;
+struct zwp_relative_pointer_manager_v1;
+struct zwp_pointer_gestures_v1;
+struct zwp_pointer_constraints_v1;
+struct zxdg_exporter_v2;
+struct zxdg_importer_v2;
+struct zwp_idle_inhibit_manager_v1;
 
 namespace KWayland
 {
@@ -63,9 +73,12 @@ class FullscreenShell;
 class OutputManagement;
 class OutputDevice;
 class Idle;
+class IdleInhibitManager;
 class Output;
 class PlasmaShell;
 class PlasmaWindowManagement;
+class PointerConstraints;
+class PointerGestures;
 class Seat;
 class ShadowManager;
 class BlurManager;
@@ -75,6 +88,15 @@ class Shell;
 class ShmPool;
 class ServerSideDecorationManager;
 class SubCompositor;
+class TextInputManager;
+class TextInputManagerUnstableV0;
+class TextInputManagerUnstableV2;
+class XdgShell;
+class RelativePointerManager;
+class XdgExporterUnstableV2;
+class XdgImporterUnstableV2;
+class XdgExporter;
+class XdgImporter;
 
 /**
  * @short Wrapper for the wl_registry interface.
@@ -132,6 +154,16 @@ public:
         OutputManagement, ///< Refers to the wl_data_device_manager interface
         OutputDevice,     ///< Refers to the org_kde_kwin_outputdevice interface
         ServerSideDecorationManager, ///< Refers to org_kde_kwin_server_decoration_manager
+        TextInputManagerUnstableV0, ///< Refers to wl_text_input_manager, @since 5.23
+        TextInputManagerUnstableV2, ///< Refers to zwp_text_input_manager_v2, @since 5.23
+        XdgShellUnstableV5, ///< Refers to xdg_shell (unstable version 5), @since 5.25
+        RelativePointerManagerUnstableV1, ///< Refers to zwp_relative_pointer_manager_v1, @since 5.28
+        PointerGesturesUnstableV1, ///< Refers to zwp_pointer_gestures_v1, @since 5.29
+        PointerConstraintsUnstableV1, ///< Refers to zwp_pointer_constraints_v1, @since 5.29
+        XdgExporterUnstableV2, ///< refers to zxdg_exporter_v2, @since 5.40
+        XdgImporterUnstableV2, ///< refers to zxdg_importer_v2, @since 5.40
+        XdgShellUnstableV6, ///< Refers to zxdg_shell_v6 (unstable version 6), @since 5.XX
+        IdleInhibitManagerUnstableV1 ///< Refers to zwp_idle_inhibit_manager_v1 (unstable version 1), @since 5.41
     };
     explicit Registry(QObject *parent = nullptr);
     virtual ~Registry();
@@ -436,6 +468,108 @@ public:
      * @since 5.6
      **/
     org_kde_kwin_server_decoration_manager *bindServerSideDecorationManager(uint32_t name, uint32_t version) const;
+    /**
+     * Binds the wl_text_input_manager with @p name and @p version.
+     * If the @p name does not exist or is not for the text input interface in unstable version 0,
+     * @c null will be returned.
+     *
+     * Prefer using createTextInputManager instead.
+     * @see createTextInputManager
+     * @since 5.23
+     **/
+    wl_text_input_manager *bindTextInputManagerUnstableV0(uint32_t name, uint32_t version) const;
+    /**
+     * Binds the zwp_text_input_manager_v2 with @p name and @p version.
+     * If the @p name does not exist or is not for the text input interface in unstable version 2,
+     * @c null will be returned.
+     *
+     * Prefer using createTextInputManager instead.
+     * @see createTextInputManager
+     * @since 5.23
+     **/
+    zwp_text_input_manager_v2 *bindTextInputManagerUnstableV2(uint32_t name, uint32_t version) const;
+    /**
+     * Binds the xdg_shell (unstable version 5) with @p name and @p version.
+     * If the @p name does not exist or is not for the xdg shell interface in unstable version 5,
+     * @c null will be returned.
+     *
+     * Prefer using createXdgShell instead.
+     * @see createXdgShell
+     * @since 5.25
+     **/
+    xdg_shell *bindXdgShellUnstableV5(uint32_t name, uint32_t version) const;
+    /**
+     * Binds the zxdg_shell_v6 (unstable version 6) with @p name and @p version.
+     * If the @p name does not exist or is not for the xdg shell interface in unstable version 5,
+     * @c null will be returned.
+     *
+     * Prefer using createXdgShell instead.
+     * @see createXdgShell
+     * @since 5.39
+     **/
+    zxdg_shell_v6 *bindXdgShellUnstableV6(uint32_t name, uint32_t version) const;
+    /**
+     * Binds the zwp_relative_pointer_manager_v1 with @p name and @p version.
+     * If the @p name does not exist or is not for the relative pointer interface in unstable version 1,
+     * @c null will be returned.
+     *
+     * Prefer using createRelativePointerManager instead.
+     * @see createRelativePointerManager
+     * @since 5.28
+     **/
+    zwp_relative_pointer_manager_v1 *bindRelativePointerManagerUnstableV1(uint32_t name, uint32_t version) const;
+    /**
+     * Binds the zwp_pointer_gestures_v1 with @p name and @p version.
+     * If the @p name does not exist or is not for the pointer gestures interface in unstable version 1,
+     * @c null will be returned.
+     *
+     * Prefer using createPointerGestures instead.
+     * @see createPointerGestures
+     * @since 5.29
+     **/
+    zwp_pointer_gestures_v1 *bindPointerGesturesUnstableV1(uint32_t name, uint32_t version) const;
+    /**
+     * Binds the zwp_pointer_constraints_v1 with @p name and @p version.
+     * If the @p name does not exist or is not for the pointer constraints interface in unstable version 1,
+     * @c null will be returned.
+     *
+     * Prefer using createPointerConstraints instead.
+     * @see createPointerConstraints
+     * @since 5.29
+     **/
+    zwp_pointer_constraints_v1 *bindPointerConstraintsUnstableV1(uint32_t name, uint32_t version) const;
+
+    /**
+     * Binds the zxdg_exporter_v2 with @p name and @p version.
+     * If the @p name does not exists or isnot for the exporter
+     * extension in unstable version 1,
+     * @c null will be returned.
+     *
+     * Prefer using createXdgExporter
+     * @since 5.40
+     */
+    zxdg_exporter_v2 *bindXdgExporterUnstableV2(uint32_t name, uint32_t version) const;
+
+    /**
+     * Binds the zxdg_importer_v2 with @p name and @p version.
+     * If the @p name does not exists or isnot for the importer
+     * extension in unstable version 1,
+     * @c null will be returned.
+     *
+     * Prefer using createXdgImporter
+     * @since 5.40
+     */
+    zxdg_importer_v2 *bindXdgImporterUnstableV2(uint32_t name, uint32_t version) const;
+
+    /**
+     * Binds the zwp_idle_inhibit_manager_v1 with @p name and @p version.
+     * If the @p name does not exists or is not for the idle inhibit manager in unstable version 1,
+     * @c null will be returned.
+     *
+     * Prefer using createIdleInhibitManager
+     * @since 5.41
+     */
+    zwp_idle_inhibit_manager_v1 *bindIdleInhibitManagerUnstableV1(uint32_t name, uint32_t version) const;
     ///@}
 
     /**
@@ -755,6 +889,142 @@ public:
      * @since 5.6
      **/
     ServerSideDecorationManager *createServerSideDecorationManager(quint32 name, quint32 version, QObject *parent = nullptr);
+    /**
+     * Creates a TextInputManager and sets it up to manage the interface identified by
+     * @p name and @p version.
+     *
+     * This factory method supports the following interfaces:
+     * @li wl_text_input_manager
+     * @li zwp_text_input_manager_v2
+     *
+     * If @p name is for one of the supported interfaces the corresponding manager will be created,
+     * otherwise @c null will be returned.
+     *
+     * @param name The name of the interface to bind
+     * @param version The version of the interface to use
+     * @param parent The parent for the TextInputManager
+     *
+     * @returns The created TextInputManager
+     * @since 5.23
+     **/
+    TextInputManager *createTextInputManager(quint32 name, quint32 version, QObject *parent = nullptr);
+    /**
+     * Creates an XdgShell and sets it up to manage the interface identified by
+     * @p name and @p version.
+     *
+     * This factory method supports the following interfaces:
+     * @li xdg_shell (Unstable version 5)
+     *
+     * If @p name is for one of the supported interfaces the corresponding shell will be created,
+     * otherwise @c null will be returned.
+     *
+     * @param name The name of the interface to bind
+     * @param version The version of the interface to use
+     * @param parent The parent for the XdgShell
+     *
+     * @returns The created XdgShell
+     * @since 5.25
+     **/
+    XdgShell *createXdgShell(quint32 name, quint32 version, QObject *parent = nullptr);
+    /**
+     * Creates a RelativePointerManager and sets it up to manage the interface identified by
+     * @p name and @p version.
+     *
+     * This factory method supports the following interfaces:
+     * @li zwp_relative_pointer_manager_v1
+     *
+     * If @p name is for one of the supported interfaces the corresponding manager will be created,
+     * otherwise @c null will be returned.
+     *
+     * @param name The name of the interface to bind
+     * @param version The version of the interface to use
+     * @param parent The parent for the RelativePointerManager
+     *
+     * @returns The created RelativePointerManager
+     * @since 5.28
+     **/
+    RelativePointerManager *createRelativePointerManager(quint32 name, quint32 version, QObject *parent = nullptr);
+    /**
+     * Creates a PointerGestures and sets it up to manage the interface identified by
+     * @p name and @p version.
+     *
+     * This factory method supports the following interfaces:
+     * @li zwp_pointer_gestures_v1
+     *
+     * If @p name is for one of the supported interfaces the corresponding manager will be created,
+     * otherwise @c null will be returned.
+     *
+     * @param name The name of the interface to bind
+     * @param version The version of the interface to use
+     * @param parent The parent for the PointerGestures
+     *
+     * @returns The created PointerGestures
+     * @since 5.29
+     **/
+    PointerGestures *createPointerGestures(quint32 name, quint32 version, QObject *parent = nullptr);
+    /**
+     * Creates a PointerConstraints and sets it up to manage the interface identified by
+     * @p name and @p version.
+     *
+     * This factory method supports the following interfaces:
+     * @li zwp_pointer_constraints_v1
+     *
+     * If @p name is for one of the supported interfaces the corresponding manager will be created,
+     * otherwise @c null will be returned.
+     *
+     * @param name The name of the interface to bind
+     * @param version The version of the interface to use
+     * @param parent The parent for the PointerConstraints
+     *
+     * @returns The created PointerConstraints
+     * @since 5.29
+     **/
+    PointerConstraints *createPointerConstraints(quint32 name, quint32 version, QObject *parent = nullptr);
+
+    /**
+     * Creates an XdgExporter and sets it up to manage the interface identified by
+     * @p name and @p version.
+     *
+     * This factory method supports the following interfaces:
+     * @li zxdg_exporter_v2
+     *
+     * If @p name is for one of the supported interfaces the corresponding manager will be created,
+     * otherwise @c null will be returned.
+     *
+     * @returns The created XdgExporter
+     * @since 5.40
+     */
+    XdgExporter *createXdgExporter(quint32 name, quint32 version, QObject *parent = nullptr);
+
+    /**
+     * Creates an XdgImporter and sets it up to manage the interface identified by
+     * @p name and @p version.
+     *
+     * This factory method supports the following interfaces:
+     * @li zxdg_importer_v2
+     *
+     * If @p name is for one of the supported interfaces the corresponding manager will be created,
+     * otherwise @c null will be returned.
+     *
+     * @returns The created XdgImporter
+     * @since 5.40
+     */
+    XdgImporter *createXdgImporter(quint32 name, quint32 version, QObject *parent = nullptr);
+
+    /**
+     * Creates an IdleInhibitManager and sets it up to manage the interface identified by
+     * @p name and @p version.
+     *
+     * This factory method supports the following interfaces:
+     * @li zwp_idle_inhibit_manager_v1
+     *
+     * If @p name is for one of the supported interfaces the corresponding manager will be created,
+     * otherwise @c null will be returned.
+     *
+     * @returns The created IdleInhibitManager
+     * @since 5.41
+     */
+    IdleInhibitManager *createIdleInhibitManager(quint32 name, quint32 version, QObject *parent = nullptr);
     ///@}
 
     /**
@@ -902,6 +1172,80 @@ Q_SIGNALS:
      * @since 5.6
      **/
     void serverSideDecorationManagerAnnounced(quint32 name, quint32 version);
+    /**
+     * Emitted whenever a wl_text_input_manager interface gets announced.
+     * @param name The name for the announced interface
+     * @param version The maximum supported version of the announced interface
+     * @since 5.23
+     **/
+    void textInputManagerUnstableV0Announced(quint32 name, quint32 version);
+    /**
+     * Emitted whenever a zwp_text_input_manager_v2 interface gets announced.
+     * @param name The name for the announced interface
+     * @param version The maximum supported version of the announced interface
+     * @since 5.23
+     **/
+    void textInputManagerUnstableV2Announced(quint32 name, quint32 version);
+    /**
+     * Emitted whenever a xdg_shell (unstable version 5) interface gets announced.
+     * @param name The name for the announced interface
+     * @param version The maximum supported version of the announced interface
+     * @since 5.25
+     **/
+    void xdgShellUnstableV5Announced(quint32 name, quint32 version);
+    /**
+     * Emitted whenever a zxdg_shell_v6 (unstable version 6) interface gets announced.
+     * @param name The name for the announced interface
+     * @param version The maximum supported version of the announced interface
+     * @since 5.25
+     **/
+    void xdgShellUnstableV6Announced(quint32 name, quint32 version);
+
+    /**
+     * Emitted whenever a zwp_relative_pointer_manager_v1 interface gets announced.
+     * @param name The name for the announced interface
+     * @param version The maximum supported version of the announced interface
+     * @since 5.28
+     **/
+    void relativePointerManagerUnstableV1Announced(quint32 name, quint32 version);
+    /**
+     * Emitted whenever a zwp_pointer_gestures_v1 interface gets announced.
+     * @param name The name for the announced interface
+     * @param version The maximum supported version of the announced interface
+     * @since 5.29
+     **/
+    void pointerGesturesUnstableV1Announced(quint32 name, quint32 version);
+    /**
+     * Emitted whenever a zwp_pointer_constraints_v1 interface gets announced.
+     * @param name The name for the announced interface
+     * @param version The maximum supported version of the announced interface
+     * @since 5.29
+     **/
+    void pointerConstraintsUnstableV1Announced(quint32 name, quint32 version);
+
+    /**
+     * Emitted whenever a zxdg_exporter_v2 interface gets announced.
+     * @param name The name for the announced interface
+     * @param version The maximum supported version of the announced interface
+     * @since 5.40
+     */
+    void exporterUnstableV2Announced(quint32 name, quint32 version);
+
+    /**
+     * Emitted whenever a zxdg_importer_v2 interface gets announced.
+     * @param name The name for the announced interface
+     * @param version The maximum supported version of the announced interface
+     * @since 5.40
+     */
+    void importerUnstableV2Announced(quint32 name, quint32 version);
+
+    /**
+     * Emitted whenever a zwp_idle_inhibit_manager_v1 interface gets announced.
+     * @param name The name for the announced interface
+     * @param version The maximum supported version of the announced interface
+     * @since 5.41
+     */
+    void idleInhibitManagerUnstableV1Announced(quint32 name, quint32 version);
     ///@}
     /**
      * @name Interface removed signals.
@@ -1019,6 +1363,69 @@ Q_SIGNALS:
      * @since 5.6
      **/
     void serverSideDecorationManagerRemoved(quint32 name);
+    /**
+     * Emitted whenever a wl_text_input_manager interface gets removed.
+     * @param name The name for the removed interface
+     * @since 5.23
+     **/
+    void textInputManagerUnstableV0Removed(quint32 name);
+    /**
+     * Emitted whenever a zwp_text_input_manager_v2 interface gets removed.
+     * @param name The name for the removed interface
+     * @since 5.23
+     **/
+    void textInputManagerUnstableV2Removed(quint32 name);
+    /**
+     * Emitted whenever an xdg_shell (unstable version 5) interface gets removed.
+     * @param name The name for the removed interface
+     * @since 5.25
+     **/
+    void xdgShellUnstableV5Removed(quint32 name);
+    /**
+     * Emitted whenever an xdg_shell (unstable version 5) interface gets removed.
+     * @param name The name for the removed interface
+     * @since 5.25
+     **/
+    void xdgShellUnstableV6Removed(quint32 name);
+    /**
+     * Emitted whenever a zwp_relative_pointer_manager_v1 interface gets removed.
+     * @param name The name for the removed interface
+     * @since 5.28
+     **/
+    void relativePointerManagerUnstableV1Removed(quint32 name);
+    /**
+     * Emitted whenever a zwp_pointer_gestures_v1 interface gets removed.
+     * @param name The name for the removed interface
+     * @since 5.29
+     **/
+    void pointerGesturesUnstableV1Removed(quint32 name);
+    /**
+     * Emitted whenever a zwp_pointer_constraints_v1 interface gets removed.
+     * @param name The name for the removed interface
+     * @since 5.29
+     **/
+    void pointerConstraintsUnstableV1Removed(quint32 name);
+
+    /**
+     * Emitted whenever a zxdg_exporter_v2 interface gets removed.
+     * @param name The name for the removed interface
+     * @since 5.40
+     **/
+    void exporterUnstableV2Removed(quint32 name);
+
+    /**
+     * Emitted whenever a zxdg_importer_v2 interface gets removed.
+     * @param name The name for the removed interface
+     * @since 5.40
+     **/
+    void importerUnstableV2Removed(quint32 name);
+
+    /**
+     * Emitted whenever a zwp_idle_inhibit_manager_v1 interface gets removed.
+     * @param name The name of the removed interface
+     * @since 5.41
+     **/
+    void idleInhibitManagerUnstableV1Removed(quint32 name);
     ///@}
     /**
      * Generic announced signal which gets emitted whenever an interface gets
@@ -1052,6 +1459,12 @@ Q_SIGNALS:
      **/
     void interfacesAnnounced();
 
+Q_SIGNALS:
+    /*
+     * Emitted when the registry has been destroyed rather than released
+     */
+    void registryDestroyed();
+
 private:
     class Private;
     QScopedPointer<Private> d;
